Stan Math Library: stan/math/rev/core/operator_less_than.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

operator_less_than.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_OPERATOR_LESS_THAN_HPP
2 #define STAN_MATH_REV_CORE_OPERATOR_LESS_THAN_HPP
3
4 #include <stan/math/rev/core/var.hpp>
5
6 namespace stan {
7 namespace math {
8
24 inline bool operator<(const var& a, const var& b) {
25 return a.val() < b.val();
26 }
27
36 inline bool operator<(const var& a, const double b) {
37 return a.val() < b;
38 }
39
48 inline bool operator<(const double a, const var& b) {
49 return a < b.val();
50 }
51
52 }
53 }
54 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
var.hpp
stan::math::operator<
bool operator<(const fvar< T > &x, double y)
Definition: operator_less_than.hpp:12
stan::math::var::val
double val() const
Return the value of this variable.
Definition: var.hpp:233

[ Stan Home Page ] © 2011–2016, Stan Development Team.